<?php


/**
 * @file
 * Admin callbacks for the Chuck module.
 */

/**
 * Implementation of hook_admin_settings()
 */
function chuck_admin_settings_form(&$form_state) {

  $form['chuck_roundhouse_kicks'] = array(
    '#type' => 'checkboxes', 
    '#title' => t('Default options'), 
    '#default_value' => variable_get('chuck_roundhouse_kicks', array()),
    '#options' => array(
      'chuck_rhk_logging' => t('Roundhouse Kick Logging'), 
      'chuck_rhk_html' => t('Roundhouse Kick HTML'), 
      'chuck_rhk_permissions' => t('Roundhouse Kick Permissions'), 
    ),
    '#description' => t('Users with the <em>administer roundehouse kicks</em> permission will be able to override these options.'),
  );
  
  $enabled = chuck_rhks_enabled();
  if($enabled['chuck_rhk_logging']){
    $form['chuck_add_libraries'] = array(
       '#type' => 'fieldset',
       '#title' => t('Installed Logging Libraries'),
       '#collapsible' => true,
       '#collapsed' => false
    );
    $form['chuck_add_libraries']['libraries'] = chuck_get_writable_form();
    $form['chuck_add_libraries']['Chrome'] = chuck_admin_get_chrome();
    $form['chuck_add_libraries']['Firefox'] = chuck_admin_get_firefox();
  }
  return system_settings_form($form);
}

/**
 *  Function call to get the status of chrome library and install it if desired.
 */
 function chuck_admin_get_chrome(){
   $lib_path = libraries_get_path('chromephp');
   if (file_exists($lib_path . '/ChromePhp.php')) {
     return array(
       '#prefix' => '<div class="messages status">',
       '#suffix' => '</div>',
       '#value' => t('<p><strong>ChromePHP Library:</strong> Installed and available.</p>'),
     );
   } else {
     return array(
       '#prefix' => '<div class="messages error">',
       '#suffix' => '</div>',
       '#value' => t('<p><strong>ChromePHP Library:</strong> Not Found. '
         .(chuck_check_writable() ? '<a href="/admin/settings/chuck/install/ChromePHP">Click here to install it.</a>' : '') .'</p>')
     );
   }
 }
 
 function chuck_admin_get_firefox(){
   $lib_path = libraries_get_path('FirePHPCore');
   if (file_exists($lib_path . '/lib/FirePHPCore/fb.php')) {
     return array(
       '#prefix' => '<div class="messages status">',
       '#suffix' => '</div>',
       '#value' => '<p><strong>FirePHP Library:</strong> Installed and available.</p>',
     );
   } else {
   
   
     return array(
       '#prefix' => '<div class="messages error">',
       '#suffix' => '</div>',
       '#value' => '<p><strong>FirePHP Library:</strong> Not Found.'
         .(chuck_check_writable() ? ' <a href="/admin/settings/chuck/install/FirePHP">Click here to install it.</a>' : '') .'</p>',
     );
   }
 }
 
 function chuck_check_writable(){
   return is_writable(getcwd().'/sites/all/libraries');
 }
 
 function chuck_get_writable_form(){
   if(chuck_check_writable()){
     return array('');
   }else {
     return array(
       '#prefix' => '<div class="messages error">',
       '#suffix' => '</div>',
       '#value' => '<p>The Libraries directory is not writable - please see <a href="/' . drupal_get_path('module', 'chuck') .'/INSTALL.txt">INSTALL.txt</a> for more information on how to manually install Logging libraries.</p>'
     );
   }
 }
 
/**
* A callback for ChromePHP that avoids caching of the output (which used to happen when directly serving a file
* from sites/default/files). This is more secuire, as well, since file is not directly accessible.
*/
function chuck_logger_chrome_response() {  
  $headers[] = "Cache-Control: no-cache, must-revalidate"; // HTTP/1.1
  $headers[] = "Expires: Sat, 26 Jul 1997 05:00:00 GMT"; // Date in the past
  $source = file_directory_temp() . '/last_run.json';
  file_transfer($source, $headers); 
}
