<?php


/**
 * @file
 * Implementations logging roundhouse kick.
 */
 
 /**
 * Shortcut method implementation.
 */
 function _rhk_log_execute($object, $label = '', $severity = 'log') {
   static $logger;
   
   if (empty ($logger)) {
     $rhks = chuck_rhks_enabled();
     if (!empty($rhks['chuck_rhk_logging'])) {
       $logger = $rhks['chuck_rhk_logging'];
     }    
   }
   
   //-- If we were able to initialize at least one logger, try to log
   if (!empty($logger) && $logger->logger_activated) {  
     $logger->log($object, $label, $severity);
   }
 }
 
  
abstract class chuck_rhk_logging implements i_chuck_rh_kick {
 
   var $logger_activated = FALSE;
      
   abstract function activate_logger();
   abstract function log($object, $label = '', $severity = 'log');
   
   static function allowed_severities() {
     return array('log', 'warn', 'error');
   }
   
   static function default_label() {
     return t('Chuck Said: ');
   }
   
   static function get_instance() {     
     //-- Centrally block unauthorized access.
     if (!user_access('use logging roundhouse kick')) {
       return NULL;
     }
     
     $agent = self::parse_user_agent();
     $clazz = "chuck_rhk_logging_" . $agent;
     if (class_exists($clazz)) {
       $ret = new $clazz();
       $ret->activate_logger();
       return $ret;
     }
     else { return NULL; }
   }
   
   /**
   * returns browser identifier key based on the raw user agent information.
   */
   static function parse_user_agent() {
     $agent_info_raw = $_SERVER['HTTP_USER_AGENT'];
     if (strpos($agent_info_raw, 'Chrome/')) {
       return "chrome";
     }
     else if (strpos($agent_info_raw, 'Firefox/')) {
       return "firefox";
     }
     
     return 'unsupported_browser';
   }
      
}
  
class chuck_rhk_logging_chrome extends chuck_rhk_logging {

  function log($object, $label = '', $severity = 'log') {
    //-- Do not try to log during logger's XMLHTTPRequest call!
    if (arg(0) == 'chuck_logging_chrome') {
      return;
    }
    
    if (!in_array($severity, self::allowed_severities())) {
      $severity = 'log';
    }

    if (empty($label)) {
      $label = self::default_label();
    }
    
    if (class_exists('ChromePhp')) {
      ChromePhp::$severity($label, $object);
    }

  }
    
  function activate_logger() {
    $lib_path = libraries_get_path('chromephp');
    if (file_exists($lib_path . '/ChromePhp.php')) {
      require_once($lib_path . '/ChromePhp.php');
      // Use file storage to avoid 4KB cookie problems.
      $file_dir_path = file_directory_temp();
      // Transfer file with a callback to avoid caching.
      ChromePhp::useFile(realpath($file_dir_path), '/chuck_logging_chrome');
      $this->logger_activated = TRUE;
    }
  }
    
}

class chuck_rhk_logging_firefox extends chuck_rhk_logging {

  function log($object, $label = '', $severity = 'log') {
    if (!in_array($severity, self::allowed_severities())) {
      $severity = 'log';
    }

    if (empty($label)) {
      $label = self::default_label();
    }

    if (function_exists('fb') && class_exists('FB')) {
      call_user_func_array(array('FB', $severity), array($object, $label));
    }
  }
    
  function activate_logger() {
    
    if (module_exists('libraries')) {
      $path = libraries_get_path('FirePHPCore') . '/lib/FirePHPCore/';
    }
    //-- devel has a bug that if libraries module is installed but FirePHPCore is under devel, it can not find it. 
    //-- We fix it here.
    if (!file_exists($path .'fb.php')) {
      $path = './'. drupal_get_path('module', 'devel') .'/FirePHPCore/lib/FirePHPCore/';
    }    
    if (file_exists($path .'fb.php')) {
      include_once $path .'fb.php';
      include_once $path .'FirePHP.class.php';
      $this->logger_activated = TRUE;
    }
  }
    
}